AllocatedSSA class

Inheritance

Constructors

AllocatedSSA(String name, int register, {int version = -1, int type = -1})
AllocatedSSA.fromSSA(SSA ssa, int register)
factory

Properties

alloc AllocatedSSA
no setterinherited
hashCode int
The hash code for this object.
no setteroverride
imm ImmediateSSA
no setterinherited
name String
The name of the variable.
finalinherited
register int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type int
The type of the variable.
getter/setter pairinherited
version int
The version of the variable.
getter/setter pairinherited

Methods

copy() AllocatedSSA
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override