AssembleContext<T> class

Constructors

AssembleContext(T data)

Properties

currentBlockId int
The block ID of the block currently being assembled. Set by the assembler before processing each block's operations.
getter/setter pair
data → T
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
successorBlockIds List<int>
The block IDs of the successors of currentBlockId, in edge-insertion order. For a conditional branch the first entry is the "true" target and the second is the "false" / fall-through target.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited