Assign class

Inheritance

Constructors

Assign(SSA target, SSA source)

Properties

hashCode int
The hash code for this object.
no setteroverride
isRematerializable bool
Whether this operation is rematerializable. Rematerializable operations can be recomputed on-the-fly and do not need to be spilled to memory.
no setterinherited
readsFrom Set<SSA>
The set of variables that are read from by this operation.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source SSA
final
target SSA
final
type OpType
The basic type of the operation, if it represents one. Used for various optimizations and transformations.
no setteroverride
writesTo SSA?
The set of variables that are written to by this operation.
no setteroverride

Methods

copyWith({SSA? writesTo, Set<SSA>? readsFrom}) Operation
Creates a copy of this operation with the given writesTo and readsFrom variables.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override