AssignmentOp enum

An operation type that represents assignment operations.

Inheritance
Implemented types
Available extensions

Values

assign → const AssignmentOp
assignIndirect → const AssignmentOp
addAssign → const AssignmentOp
subtractAssign → const AssignmentOp
multiplyAssign → const AssignmentOp
divideAssign → const AssignmentOp
moduloAssign → const AssignmentOp

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
inner OpType?
The inner operation type of this assignment operation. For example, addAssign has an inner operation type of ArithmeticOp.add.
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AssignmentOp>
A constant List of the values in this enum, in order of their declaration.