Creator<T extends Operation, C> class

Implemented types

Constructors

Creator({Set<int> clobberedRegisters = const {}, required Set<Variant> variants, required Instruction create(T operation, AssembleContext<C> context)})
const

Properties

clobberedRegisters Set<int>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
variants Set<Variant>
final

Methods

createInstruction(T operation, AssembleContext<C> context) Instruction
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited