ImmediateSSA class

Inheritance

Constructors

ImmediateSSA(String name, Object? value, {int version = -1, int type = -1})
ImmediateSSA.fromSSA(SSA ssa, Object? value)
factory

Properties

alloc AllocatedSSA
no setterinherited
hashCode int
The hash code for this object.
no setteroverride
imm ImmediateSSA
no setterinherited
name String
The name of the variable.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type int
The type of the variable.
getter/setter pairinherited
value Object?
final
version int
The version of the variable.
getter/setter pairinherited

Methods

copy() ImmediateSSA
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override