Operation class abstract

Defines an SSA operation in a program's BasicBlock. The operation must specify which variables it reads from and writes to.

Implementers

Constructors

Operation()

Properties

hashCode int
The hash code for this object.
no setterinherited
isRematerializable bool
Whether this operation is rematerializable. Rematerializable operations can be recomputed on-the-fly and do not need to be spilled to memory.
no setter
readsFrom Set<SSA>
The set of variables that are read from by this operation.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type OpType
The basic type of the operation, if it represents one. Used for various optimizations and transformations.
no setter
writesTo SSA?
The set of variables that are written to by this operation.
no setter

Methods

copyWith({SSA? writesTo, Set<SSA>? readsFrom}) Operation
Creates a copy of this operation with the given writesTo and readsFrom variables.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited