copyWith method
Creates a copy of this operation with the given writesTo and readsFrom
variables.
Implementation
@override
Operation copyWith({SSA? writesTo, Set<SSA>? readsFrom}) {
return PhiNode(writesTo ?? target, readsFrom ?? sources);
}
Creates a copy of this operation with the given writesTo and readsFrom
variables.
@override
Operation copyWith({SSA? writesTo, Set<SSA>? readsFrom}) {
return PhiNode(writesTo ?? target, readsFrom ?? sources);
}