SwapOp class
Swaps the physical register contents of two SSA variables in place.
Both variables must share at least one RegisterGroup parent (i.e. belong
to the same RegType) for a swap to be legal.
Properties
- a → SSA
-
final
- b → SSA
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isRematerializable → bool
-
Whether this operation is rematerializable. Rematerializable operations
can be recomputed on-the-fly and do not need to be spilled to memory.
no setterinherited
-
readsFrom
→ Set<
SSA> -
The set of variables that are read from by this operation.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → OpType
-
The basic type of the operation, if it represents one. Used for various
optimizations and transformations.
no setteroverride
- writesTo → SSA?
-
The set of variables that are written to by this operation.
no setteroverride
Methods
-
copyWith(
{SSA? writesTo, Set< SSA> ? readsFrom}) → Operation -
Creates a copy of this operation with the given
writesToandreadsFromvariables.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override