BasicBlock<T extends Operation> class
A basic block is a sequence of operations that are always executed together. Only the last operation may perform control flow (e.g. a branch or jump).
Constructors
-
BasicBlock(List<
T> code, {String? label}) -
Creates a new basic block with the given
codeand optionallabel.
Properties
-
code
→ List<
T> -
The operations in this block. Only the last operation may perform control
flow (e.g. a branch or jump).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ int?
-
The unique identifier of this block in a control flow graph.
getter/setter pair
- label → String?
-
An optional label for this block.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
describe(
) → String - Describes the basic block and its operations.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited