InstructionCreator<T extends Operation, C> class
abstract
- Implementers
Constructors
Properties
-
clobberedRegisters
→ Set<
int> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
variants
→ Set<
Variant> ? -
no setter
Methods
-
createInstruction(
T operation, AssembleContext< C> context) → Instruction -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited