MoveCallback<C> typedef
MoveCallback<C> =
Instruction Function(AllocatedSSA target, AllocatedSSA source, AssembleContext<C> context)
Callback type for emitting a register-to-register move instruction.
Corresponds to a synthesised Assign operation inserted by the register allocator to shuffle values between physical registers.
Implementation
typedef MoveCallback<C> = Instruction Function(
AllocatedSSA target, AllocatedSSA source, AssembleContext<C> context);