SSA class
A static single assignment (SSA) form variable.
- Implementers
Constructors
Properties
- alloc → AllocatedSSA
-
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- imm → ImmediateSSA
-
no setter
- name → String
-
The name of the variable.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ int
-
The type of the variable.
getter/setter pair
- version ↔ int
-
The version of the variable.
getter/setter pair
Methods
-
copy(
) → SSA -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override