Variant class
Properties
-
arguments
→ List<int>
-
List of register indices that the instruction reads from
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
result
→ int?
-
Register index that the instruction writes to, or null if it doesn't write to any register
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited